import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * The class Mover provides some basic movement methods. Use this as a superclass
 * for other actors that should be able to move left and right, jump up and fall 
 * down.
 */
public class Mover extends Actor
{
    private static final int acceleration = 1;      // down (gravity)
    private static final int speed = 3;             // running speed (sideways)
    private Actor actor;
    private int vSpeed = 0;                         // current vertical speed

    public void moveRight()
    {
        setLocation ( getX() + speed, getY() );
    }

    public void moveLeft()
    {
        setLocation ( getX() - speed, getY() );
    }

    public boolean onGround()
    {
        actor = getOneObjectAtOffset(0, getImage().getHeight()/2 , tile.class);
        return actor != null;
    }

    public boolean blockRight()
    {
        actor = getOneObjectAtOffset(getImage().getWidth()/2,0, tile.class);
        return actor!= null;
    }

    public boolean blockLeft()
    {
        actor = getOneObjectAtOffset(-getImage().getWidth()/2 ,0, tile.class);
        return actor != null;
    }

    public boolean blockTop()
    {
        actor = getOneObjectAtOffset(0 ,-getImage().getHeight()/2, tile.class);
        return actor != null;
    }

    public void setVSpeed(int speed)
    {
        vSpeed = speed;
    }

    public void fall()
    {

        setLocation ( getX(), getY() + vSpeed);
        vSpeed = vSpeed + acceleration;
        if ( atBottom() )
            gameEnd();

    }

    private boolean atBottom()
    {
        return getY() >= getWorld().getHeight()+32;
    }

    private void gameEnd()
    {
        ((CherryWorld)getWorld()).gameOver("Failed!");
        Greenfoot.stop();
    }

    public void scroll(){  //scrolling all the actors except player
        if(CherryWorld.canScrollLeft&& Greenfoot.isKeyDown("d")){ 
            moveLeft();
        }
        else if(CherryWorld.canScrollRight&& Greenfoot.isKeyDown("a")){ 
            moveRight();
        }
    }


}
